# `gh0st`

```
   _____ _    _  ____   _____ _______ 
  / ____| |  | |/ __ \ / ____|__   __|
 | |  __| |__| | | /  | (___    | |   
 | | |_ |  __  | |//| |\___ \   | |   
 | |__| | |  | |  /_| |____) |  | |   
  \_____|_|  |_|\____/|_____/   |_|   
```

A top-down stealth and hacking game implemented in python curses  
Playable in 256-color terminal emulators to monochrome tty and everything in between

## Files

|                  File | Description |
|----------------------:|:------------|
| `gh0st/`              | gh0st package |
| coming soon			| published after restructuring |


## Download and Play

```bash
$ pip install gh0st
$ gh0st
```

## TODO

### Key
[**+**] feature to be added  
[**x**] change in code  
[**-**] bug to be removed  
[**?**] uncertain how to proceed  

### Tasks

[**+**] add badges to gitlab <3  
[**+**] upload to PyPI  
`├──`   write working demo  
`└──`   tag first release  
[**+**] SE logic needs to be fuzzy, contradictable, and maybe not all revealed, but able to reveal by prodding/getting skill/familiarity?  
`└──`   SE demo?  
[**+**] Need to keep better track of window size to prevent errors from making and using windows that are larger  
[**+**] match window size on create&resize  
[**+**] use old option&menu as base class?  